<div align='center'> <h1> MagnetoPyElastica </h1> </div>

[![CI][badge-CI]][link-CI]  [![codecov][badge-codecov]][link-codecov] [![DOI][badge-doi]][link-doi]

MagnetoPyElastica is an *open-source* project for simulating magnetic Cosserat rods interacting with external magnetic environments, and is an extension of [PyElastica][pyelastica-repo].

https://user-images.githubusercontent.com/33580851/185485978-f5962c41-89a4-4df7-b935-1ba92a55f1da.mov

[//]: # ([![gallery][link-readme-gallary]][link-project-website])

Visit [cosseratrods.org][link-project-website] to learn more about Elastica and Cosserat rod theory.

## Installation

[//]: # ([![PyPI version][badge-pypi]][link-pypi])

MagnetoPyElastica is compatible with Python 3.8 - 3.10. The easiest way to install MagnetoPyElastica is with PIP.

~~~bash
$ pip install magneto_pyelastica
~~~

[//]: # (## Documentation)

[//]: # ([![Documentation Status][badge-docs-status]][link-docs-status])

[//]: # ()
[//]: # (Documentation of PyElastica is available [here][link-docs-website])

## Tutorials

We have included example scripts for some illustration cases and these scripts located under examples folder ([`examples/`](examples/)).


## Contribution

If you would like to participate, please read our [contribution guideline](CONTRIBUTING.md)

MagnetoPyElastica is developed by the [Gazzola Lab][link-lab-website] at the University of Illinois at Urbana-Champaign.

## Citation

```
@software{yashraj_bhosale_2023_7658892,
  author       = {Yashraj Bhosale and
                  Arman Tekinalp},
  title        = {{MagnetoPyElastica:  Open-source software for 
                   simulating magnetic Cosserat rods}},
  month        = feb,
  year         = 2023,
  publisher    = {Zenodo},
  version      = {v.0.0.1.post1},
  doi          = {10.5281/zenodo.7658892},
  url          = {https://doi.org/10.5281/zenodo.7658892}
}
```

## Senior Developers ✨
_Names arranged alphabetically_
- [Arman Tekinalp](https://github.com/armantekinalp)
- [Yashraj Bhosale](https://github.com/bhosale2)

[//]: # (Collection of URLs.)

[//]: # ([link-readme-gallary]: https://github.com/skim0119/PyElastica/blob/assets_logo/assets/alpha_gallery.gif)

[link-project-website]: https://cosseratrods.org
[link-lab-website]: http://mattia-lab.com/
[link-docs-website]: https://docs.cosseratrods.org/

[badge-CI]: https://github.com/armantekinalp/MagnetoPyElastica/workflows/CI/badge.svg
[badge-codecov]: https://codecov.io/gh/armantekinalp/MagnetoPyElastica/branch/main/graph/badge.svg
[badge-doi]: https://zenodo.org/badge/513349542.svg
[link-CI]: https://github.com/armantekinalp/MagnetoPyElastica/actions
[link-codecov]: https://codecov.io/gh/armantekinalp/MagnetoPyElastica
[link-doi]: https://zenodo.org/badge/latestdoi/513349542
[pyelastica-repo]: ttps://github.com/GazzolaLab/PyElastica
